@@ -69,12 +69,12 @@ class WmsTileLayer(Layer):
             var {{this.get_name()}} = L.tileLayer.wms(
                 '{{ this.url }}',
                 {
-                    layers:'{{ this.layers }}',
+                    layers: '{{ this.layers }}',
                     styles: '{{ this.styles }}',
-                    format:'{{ this.format }}',
+                    format: '{{ this.format }}',
                     transparent: {{ this.transparent.__str__().lower() }},
                     version: '{{ this.version }}',
-                    {% if this.attribution %}, attribution:'{{this.attribution}}'{% endif %}
+                    {% if this.attribution %} attribution: '{{this.attribution}}'{% endif %}
                     }
                 ).addTo({{this._parent.get_name()}});
 
@@ -507,12 +507,12 @@ class TopoJson(Layer):
                 ymax = none_max(y, ymax)
         return [
             [
-                self.data['transform']['translate'][0] + self.data['transform']['scale'][0] * xmin,  # noqa
                 self.data['transform']['translate'][1] + self.data['transform']['scale'][1] * ymin,  # noqa
+                self.data['transform']['translate'][0] + self.data['transform']['scale'][0] * xmin  # noqa
             ],
             [
-                self.data['transform']['translate'][0] + self.data['transform']['scale'][0] * xmax,  # noqa
                 self.data['transform']['translate'][1] + self.data['transform']['scale'][1] * ymax,  # noqa
+                self.data['transform']['translate'][0] + self.data['transform']['scale'][0] * xmax  # noqa
             ]
 
         ]
